==> qt-creator-opensource-src-4.1.0.tar.gz: qt-creator-opensource-src-4.1.0/tests/unit/unittest/chunksreportedmonitor.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "chunksreportedmonitor.h"

#include <QSignalSpy>

namespace ClangBackEnd {

ChunksReportedMonitor::ChunksReportedMonitor(const QFuture<TextEditor::HighlightingResult> &future)
    : m_future(future)
{
    m_futureWatcher.setFuture(future);
    connect(&m_futureWatcher, &QFutureWatcher<TextEditor::HighlightingResult>::resultsReadyAt,
            this, &ChunksReportedMonitor::onResultsReadyAt);
}

bool ChunksReportedMonitor::waitUntilFinished(int timeoutInMs)
{
    QSignalSpy spy(&m_futureWatcher, SIGNAL(finished()));
    return spy.wait(timeoutInMs);
}

void ChunksReportedMonitor::onResultsReadyAt(int beginIndex, int endIndex)
{
    Q_UNUSED(beginIndex)
    Q_UNUSED(endIndex)
    ++m_resultsReadyCounter;
}

uint ChunksReportedMonitor::resultsReadyCounter()
{
    waitUntilFinished();
    return m_resultsReadyCounter;
}

} // namespace ClangBackEnd

==> qt-creator-opensource-src-4.10.1.tar.gz: qt-creator-opensource-src-4.10.1/tests/unit/unittest/chunksreportedmonitor.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "googletest.h"

#include "chunksreportedmonitor.h"

#include <QSignalSpy>

namespace ClangBackEnd {

ChunksReportedMonitor::ChunksReportedMonitor(const QFuture<TextEditor::HighlightingResult> &future)
    : m_future(future)
{
    connect(&m_futureWatcher, &QFutureWatcher<TextEditor::HighlightingResult>::resultsReadyAt,
            this, &ChunksReportedMonitor::onResultsReadyAt);
    m_futureWatcher.setFuture(future);
}

bool ChunksReportedMonitor::waitUntilFinished(int timeoutInMs)
{
    QSignalSpy spy(&m_futureWatcher, SIGNAL(finished()));
    return spy.wait(timeoutInMs);
}

void ChunksReportedMonitor::onResultsReadyAt(int, int)
{
    ++m_resultsReadyCounter;
}

uint ChunksReportedMonitor::resultsReadyCounter()
{
    waitUntilFinished();
    return m_resultsReadyCounter;
}

} // namespace ClangBackEnd
